@@ -115,7 +115,9 @@ def _dispatch_select(
             result = build_union(command)
         case CommandType.INTERSECT:
             result = build_intersect(command)
-        case command.cmd_type if command.cmd_type in _SELECT_ADD_CMD or CommandType:
+        case command.cmd_type if (
+            command.cmd_type in _SELECT_ADD_CMD or command.cmd_type in list(CommandType)
+        ):
             pass
         # The following case is just an other security layers,
         # but we can't go in this case for the moment.
