@@ -304,7 +304,7 @@ class SQLEnumerable:
                 if self.flags.join:
                     raise GroupByWithJoinError()
                 self._check_legality_terminal_alter(cmd)
-            case cmd if cmd in Ct:  # type: ignore[operator] # HACK
+            case cmd if cmd in list(Ct):  # type: ignore[operator] # HACK
                 self._check_legality_terminal_alter(cmd)
             # The following case is just an other security layers,
             # but we can't go in this case for the moment.
